@@ -1,4 +1,9 @@
-from dataservice.clients import HttpXClient, PlaywrightClient, PlaywrightPage
+from dataservice.clients import (
+    PLAYWRIGHT_AVAILABLE,
+    HttpXClient,
+    PlaywrightClient,
+    PlaywrightPage,
+)
 from dataservice.config import (
     CacheConfig,
     RateLimiterConfig,
@@ -11,6 +16,19 @@ from dataservice.logs import setup_logging
 from dataservice.models import FailedRequest, Request, Response
 from dataservice.service import AsyncDataService, DataService
 
+
+def check_playwright_availability():
+    if not PLAYWRIGHT_AVAILABLE:
+        raise ImportError(
+            "Playwright optional dependency is not installed. Please install it with `pip install python-dataservice[playwright]`."
+        )
+
+
+# Check availability when importing PlaywrightClient or PlaywrightPage
+if "PlaywrightClient" in globals() or "PlaywrightPage" in globals():
+    check_playwright_availability()
+
+
 __all__ = [
     "AsyncDataService",
     "BaseDataItem",
